tbf_dl: Avoid attempt scheduling DL ACK/NACK in TS != CTRL TS

Change-Id: I80cddc80f23992fd86637980f9e2bfc00a50e04e
diff --git a/src/tbf_dl.cpp b/src/tbf_dl.cpp
index f799cb0..ba0cee2 100644
--- a/src/tbf_dl.cpp
+++ b/src/tbf_dl.cpp
@@ -788,8 +788,9 @@
 		m_last_dl_poll_fn = fn;
 
 	/* poll after POLL_ACK_AFTER_FRAMES frames, or when final block is tx or
-	 * when last polled DL ACK/NACK was lost. */
-	if (need_poll_for_dl_ack_nack()) {
+	 * when last polled DL ACK/NACK was lost. Always do so in the control TS. */
+	if (tbf_is_control_ts(dl_tbf_as_tbf(this), pdch) &&
+	    need_poll_for_dl_ack_nack()) {
 		if (m_dl_ack_requested) {
 			LOGPTBFDL(this, LOGL_DEBUG,
 				  "Scheduling Ack/Nack polling, because it was requested explicitly "